# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hash.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nhash.proto\x12\x04kudu*R\n\rHashAlgorithm\x12\x10\n\x0cUNKNOWN_HASH\x10\x00\x12\x11\n\rMURMUR_HASH_2\x10\x01\x12\r\n\tCITY_HASH\x10\x02\x12\r\n\tFAST_HASH\x10\x03\x42\x11\n\x0forg.apache.kudu')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hash_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017org.apache.kudu'
  _HASHALGORITHM._serialized_start=20
  _HASHALGORITHM._serialized_end=102
# @@protoc_insertion_point(module_scope)
