syntax = "proto3";

package cz.proto;

import 'object_identifier.proto';

message Share {
  ObjectIdentifier provider_workspace = 1;

  enum Kind {
    INBOUND = 0;
    OUTBOUND = 1;
  }
  // Kind is only for show shares
  Kind kind = 2;

  enum Scope {
    PRIVATE = 0;
    PUBLIC = 1;
  }
  Scope scope = 3;
}
