# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: virtual_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15virtual_cluster.proto\x12\x11\x63om.clickzetta.rm\"\xb3\x02\n\x13\x41nalyticsProperties\x12\x19\n\x0cmin_replicas\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x19\n\x0cmax_replicas\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12(\n\x1bmax_concurrency_per_replica\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x39\n\x0cscale_policy\x18\x04 \x01(\x0e\x32\x1e.com.clickzetta.rm.ScalePolicyH\x03\x88\x01\x01\x12\x1b\n\x0epreload_tables\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x0f\n\r_min_replicasB\x0f\n\r_max_replicasB\x1e\n\x1c_max_concurrency_per_replicaB\x0f\n\r_scale_policyB\x11\n\x0f_preload_tables\"h\n\x11GeneralProperties\x12>\n\x10\x63luster_max_size\x18\x01 \x01(\x0e\x32\x1f.com.clickzetta.rm.VClusterSizeH\x00\x88\x01\x01\x42\x13\n\x11_cluster_max_size\"Z\n\nVCResource\x12\x13\n\x06memory\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x1a\n\rvirtual_cores\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_memoryB\x10\n\x0e_virtual_cores\"\xd5\x07\n\x18VirtualClusterProperties\x12\x11\n\x04name\x18\x01 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0binstance_id\x18\x02 \x01(\x03H\x02\x88\x01\x01\x12\x19\n\x0cworkspace_id\x18\x03 \x01(\x03H\x03\x88\x01\x01\x12:\n\x0c\x63luster_type\x18\x04 \x01(\x0e\x32\x1f.com.clickzetta.rm.VClusterTypeH\x04\x88\x01\x01\x12:\n\x0c\x63luster_size\x18\x05 \x01(\x0e\x32\x1f.com.clickzetta.rm.VClusterSizeH\x05\x88\x01\x01\x12\x46\n\x14\x61nalytics_properties\x18\x06 \x01(\x0b\x32&.com.clickzetta.rm.AnalyticsPropertiesH\x00\x12\x42\n\x12general_properties\x18\x07 \x01(\x0b\x32$.com.clickzetta.rm.GeneralPropertiesH\x00\x12\"\n\x15\x61uto_stop_latency_sec\x18\x08 \x01(\x05H\x06\x88\x01\x01\x12\x1f\n\x12\x61uto_start_enabled\x18\t \x01(\x08H\x07\x88\x01\x01\x12\x41\n\x03tag\x18\n \x03(\x0b\x32\x34.com.clickzetta.rm.VirtualClusterProperties.TagEntry\x12\x14\n\x07\x63omment\x18\x0b \x01(\tH\x08\x88\x01\x01\x12)\n\x1cquery_process_time_limit_sec\x18\r \x01(\x05H\t\x88\x01\x01\x12\x1b\n\x0e\x63reate_time_ms\x18\x0e \x01(\x03H\n\x88\x01\x01\x12 \n\x13last_modify_time_ms\x18\x0f \x01(\x03H\x0b\x88\x01\x01\x12\x1c\n\x0f\x63reator_user_id\x18\x10 \x01(\x03H\x0c\x88\x01\x01\x12\x14\n\x07version\x18\x11 \x01(\tH\r\x88\x01\x01\x1a*\n\x08TagEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0eresource_oneofB\x07\n\x05_nameB\x0e\n\x0c_instance_idB\x0f\n\r_workspace_idB\x0f\n\r_cluster_typeB\x0f\n\r_cluster_sizeB\x18\n\x16_auto_stop_latency_secB\x15\n\x13_auto_start_enabledB\n\n\x08_commentB\x1f\n\x1d_query_process_time_limit_secB\x11\n\x0f_create_time_msB\x16\n\x14_last_modify_time_msB\x12\n\x10_creator_user_idB\n\n\x08_version\"e\n\x0bRequestInfo\x12\x17\n\nrequest_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0eoperator_token\x18\x02 \x01(\x0cH\x01\x88\x01\x01\x42\r\n\x0b_request_idB\x11\n\x0f_operator_token\"\xbf\x01\n\x0cResponseInfo\x12\x17\n\nrequest_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x19.com.clickzetta.rm.StatusH\x01\x88\x01\x01\x12\x17\n\nerror_code\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x16\n\terror_msg\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\r\n\x0b_request_idB\t\n\x07_statusB\r\n\x0b_error_codeB\x0c\n\n_error_msg*\xd0\x01\n\x0cVClusterSize\x12\n\n\x06XSMALL\x10\x00\x12\t\n\x05SMALL\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\t\n\x05LARGE\x10\x03\x12\n\n\x06XLARGE\x10\x04\x12\x0b\n\x07X2LARGE\x10\x05\x12\x0b\n\x07X3LARGE\x10\x06\x12\x0b\n\x07X4LARGE\x10\x07\x12\x0b\n\x07X5LARGE\x10\x08\x12\x0b\n\x07X6LARGE\x10\t\x12\x0f\n\x0b\x43USTOMIZED3\x10\x65\x12\x10\n\x0c\x43USTOMIZED52\x10\x66\x12\x10\n\x0c\x43USTOMIZED48\x10g\x12\x10\n\x0c\x43USTOMIZED12\x10h**\n\x0cVClusterType\x12\x0b\n\x07GENERAL\x10\x00\x12\r\n\tANALYTICS\x10\x01*\x1b\n\x0bScalePolicy\x12\x0c\n\x08STANDARD\x10\x00*\xb5\x01\n\x13VirtualClusterState\x12\r\n\tSUSPENDED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x0c\n\x08STARTING\x10\x02\x12\x0e\n\nSCALING_UP\x10\x03\x12\x10\n\x0cSCALING_DOWN\x10\x04\x12\x0e\n\nSUSPENDING\x10\x05\x12\x0c\n\x08\x44ROPPING\x10\x06\x12\t\n\x05\x45RROR\x10\x07\x12\x0b\n\x07\x44\x45LETED\x10\x08\x12\x0c\n\x08RESUMING\x10\t\x12\x0e\n\nCANCELLING\x10\n*#\n\x06Status\x12\r\n\tSUCCEEDED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x42/\n\x17\x63om.clickzetta.rm.protoB\x14VirtualClusterProtosb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'virtual_cluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.clickzetta.rm.protoB\024VirtualClusterProtos'
  _VIRTUALCLUSTERPROPERTIES_TAGENTRY._options = None
  _VIRTUALCLUSTERPROPERTIES_TAGENTRY._serialized_options = b'8\001'
  _VCLUSTERSIZE._serialized_start=1834
  _VCLUSTERSIZE._serialized_end=2042
  _VCLUSTERTYPE._serialized_start=2044
  _VCLUSTERTYPE._serialized_end=2086
  _SCALEPOLICY._serialized_start=2088
  _SCALEPOLICY._serialized_end=2115
  _VIRTUALCLUSTERSTATE._serialized_start=2118
  _VIRTUALCLUSTERSTATE._serialized_end=2299
  _STATUS._serialized_start=2301
  _STATUS._serialized_end=2336
  _ANALYTICSPROPERTIES._serialized_start=45
  _ANALYTICSPROPERTIES._serialized_end=352
  _GENERALPROPERTIES._serialized_start=354
  _GENERALPROPERTIES._serialized_end=458
  _VCRESOURCE._serialized_start=460
  _VCRESOURCE._serialized_end=550
  _VIRTUALCLUSTERPROPERTIES._serialized_start=553
  _VIRTUALCLUSTERPROPERTIES._serialized_end=1534
  _VIRTUALCLUSTERPROPERTIES_TAGENTRY._serialized_start=1229
  _VIRTUALCLUSTERPROPERTIES_TAGENTRY._serialized_end=1271
  _REQUESTINFO._serialized_start=1536
  _REQUESTINFO._serialized_end=1637
  _RESPONSEINFO._serialized_start=1640
  _RESPONSEINFO._serialized_end=1831
# @@protoc_insertion_point(module_scope)
