# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: virtual_cluster_meta.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import virtual_cluster_pb2 as virtual__cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avirtual_cluster_meta.proto\x12\x08\x63z.proto\x1a\x15virtual_cluster.proto\"\xdf\x02\n\x13\x41nalyticsProperties\x12\x19\n\x0cmin_replicas\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x19\n\x0cmax_replicas\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12(\n\x1bmax_concurrency_per_replica\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x39\n\x0cscale_policy\x18\x04 \x01(\x0e\x32\x1e.com.clickzetta.rm.ScalePolicyH\x03\x88\x01\x01\x12\x19\n\x0c\x63ur_replicas\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x1b\n\x0epreload_tables\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\x0f\n\r_min_replicasB\x0f\n\r_max_replicasB\x1e\n\x1c_max_concurrency_per_replicaB\x0f\n\r_scale_policyB\x0f\n\r_cur_replicasB\x11\n\x0f_preload_tables\"h\n\x11GeneralProperties\x12>\n\x10\x63luster_max_size\x18\x01 \x01(\x0e\x32\x1f.com.clickzetta.rm.VClusterSizeH\x00\x88\x01\x01\x42\x13\n\x11_cluster_max_size\"c\n\x07JobInfo\x12\x19\n\x0cjobs_running\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1a\n\rjobs_in_queue\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0f\n\r_jobs_runningB\x10\n\x0e_jobs_in_queue\"\xcb\x07\n\x12VirtualClusterMeta\x12\x35\n\x0c\x63luster_type\x18\x01 \x01(\x0e\x32\x1f.com.clickzetta.rm.VClusterType\x12:\n\x0c\x63luster_size\x18\x02 \x01(\x0e\x32\x1f.com.clickzetta.rm.VClusterSizeH\x01\x88\x01\x01\x12=\n\x14\x61nalytics_properties\x18\x03 \x01(\x0b\x32\x1d.cz.proto.AnalyticsPropertiesH\x00\x12\x39\n\x12general_properties\x18\x04 \x01(\x0b\x32\x1b.cz.proto.GeneralPropertiesH\x00\x12\"\n\x15\x61uto_stop_latency_sec\x18\x05 \x01(\x05H\x02\x88\x01\x01\x12\x1f\n\x12\x61uto_start_enabled\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x32\n\x03tag\x18\x07 \x03(\x0b\x32%.cz.proto.VirtualClusterMeta.TagEntry\x12)\n\x1cquery_process_time_limit_sec\x18\t \x01(\x05H\x04\x88\x01\x01\x12:\n\x05state\x18\n \x01(\x0e\x32&.com.clickzetta.rm.VirtualClusterStateH\x05\x88\x01\x01\x12>\n\tpre_state\x18\x0b \x01(\x0e\x32&.com.clickzetta.rm.VirtualClusterStateH\x06\x88\x01\x01\x12\x16\n\terror_msg\x18\x0c \x01(\tH\x07\x88\x01\x01\x12(\n\x08job_info\x18\r \x01(\x0b\x32\x11.cz.proto.JobInfoH\x08\x88\x01\x01\x12\x19\n\x0cworkspace_id\x18\x0e \x01(\x03H\t\x88\x01\x01\x12\x12\n\x05vc_id\x18\x0f \x01(\x03H\n\x88\x01\x01\x12\x17\n\nstate_info\x18\x10 \x01(\tH\x0b\x88\x01\x01\x12\x14\n\x07version\x18\x11 \x01(\tH\x0c\x88\x01\x01\x1a*\n\x08TagEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0eresource_oneofB\x0f\n\r_cluster_sizeB\x18\n\x16_auto_stop_latency_secB\x15\n\x13_auto_start_enabledB\x1f\n\x1d_query_process_time_limit_secB\x08\n\x06_stateB\x0c\n\n_pre_stateB\x0c\n\n_error_msgB\x0b\n\t_job_infoB\x0f\n\r_workspace_idB\x08\n\x06_vc_idB\r\n\x0b_state_infoB\n\n\x08_versionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'virtual_cluster_meta_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VIRTUALCLUSTERMETA_TAGENTRY._options = None
  _VIRTUALCLUSTERMETA_TAGENTRY._serialized_options = b'8\001'
  _ANALYTICSPROPERTIES._serialized_start=64
  _ANALYTICSPROPERTIES._serialized_end=415
  _GENERALPROPERTIES._serialized_start=417
  _GENERALPROPERTIES._serialized_end=521
  _JOBINFO._serialized_start=523
  _JOBINFO._serialized_end=622
  _VIRTUALCLUSTERMETA._serialized_start=625
  _VIRTUALCLUSTERMETA._serialized_end=1596
  _VIRTUALCLUSTERMETA_TAGENTRY._serialized_start=1332
  _VIRTUALCLUSTERMETA_TAGENTRY._serialized_end=1374
# @@protoc_insertion_point(module_scope)
